@@ -15,7 +15,8 @@ class KafkaReader(Reader):
                 enable_auto_commit      = self.get_option('enable_auto_commit', True),
                 auto_offset_reset       = self.get_option('auto_offset_reset', 'earliest'),
                 max_poll_records        = self.get_option('max_poll_records', 500),
-                max_poll_interval_ms    = self.get_option('max_poll_interval_ms', 300000)
+                max_poll_interval_ms    = self.get_option('max_poll_interval_ms', 300000),
+                max_partition_fetch_bytes = self.get_option('max_partition_fetch_bytes', 1*1024*1024)
             )
 
         return self.consumer
